import request from '@/utils/axios'

let base = '/treeAndTable/'

let url = {
    'Dept': base + 'dept/',
    'Job': base + 'job/',
    'User': base + 'user/'
}

// 获取dept数据
export function getDeptData(parent) {
    return request({
        url: url.Dept,
        method: 'get',
        params: parent
    })
}

// 删除接口
export function deleteDeptData(id) {
    return request({
        url: url.Dept,
        method: 'delete',
        params: id
    })
}

/**
 * 更新接口
 * 参数要有id和name
 */
export function putDeptData(data) {
    return request({
        url: url.Dept,
        method: 'put',
        data
    })
}

/**
 * 新增接口
 * 参数要有一个id和name
 */
export function postDeptData(data) {
    return request({
        url: url.Dept,
        method: 'post',
        data
    })
}

export function getJob(parent) {
    return request({
        url: url.Job,
        method: 'get',
        params: parent
    })
}

/**
 * 新增岗位到对应部门接口
 * {"dept_id":"33","name":"舍长"}
 */
export function postJob(data) {
    return request({
        url: url.Job,
        method: 'post',
        data
    })
}

// 删除岗位接口
export function deleteJob(id) {
    return request({
        url: url.Job + id + '/',
        method: 'delete',
    })
}

/**
 * 新增用户到指定部门(必须带岗位)
 * 部门岗位中间表和用户名字
 * {"dept_job_id":[1,2],"name":"linjj"}
 */
export function postUser(data) {
    return request({
        url: url.User,
        method: 'post',
        data
    })
}

/**
 * 获取指定部门的所有人员(附带该人员的所有岗位)
 * {
    {
        "id": 14,
        "user_id": 3,
        "user_name": "zangsan",
        "jobs": [
            {
                "job_id": 4,
                "job_name": "测试岗位"
            }
        ]
    },
    {
        "id": 15,
        "user_id": 2,
        "user_name": "linjj",
        "jobs": [
            {
                "job_id": 6,
                "job_name": "测试岗位1"
            }
        ]
    }
 * }
 */
export function getUsers(params) {
    return request({
        url: url.User,
        method: 'get',
        params
    })
}

// 删除用户接口
export function deleteUser(id) {
    return request({
        url: url.User + id + '/',
        method: 'delete',
    })
}